FeedGetCrosspostThreadInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

FeedGetCrosspostThreadInput({@AtUriConverter.new() required AtUri anchor, @Default.new(50) int limit, String? cursor, @Default.new(6) int depth, @Default.new(80) int parentHeight, @FeedGetCrosspostThreadSortConverter() FeedGetCrosspostThreadSort? sort, Map<String, dynamic>? $unknown})
const
factory
FeedGetCrosspostThreadInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
anchor → AtUri
Reference (AT-URI) to anchor post or reply record.
no setterinherited
copyWith → $FeedGetCrosspostThreadInputCopyWith<FeedGetCrosspostThreadInput>
Create a copy of FeedGetCrosspostThreadInput with the given fields replaced by the non-null parameter values.
no setterinherited
cursor String?
no setterinherited
depth int
How many levels of descendant depth should be included in response.
no setterinherited
hasCursor bool

Available on FeedGetCrosspostThreadInput, provided by the FeedGetCrosspostThreadInputExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
hasNotCursor bool

Available on FeedGetCrosspostThreadInput, provided by the FeedGetCrosspostThreadInputExtension extension

no setter
hasNotSort bool

Available on FeedGetCrosspostThreadInput, provided by the FeedGetCrosspostThreadInputExtension extension

no setter
hasSort bool

Available on FeedGetCrosspostThreadInput, provided by the FeedGetCrosspostThreadInputExtension extension

no setter
limit int
no setterinherited
parentHeight int
How many levels of parent (and grandparent, etc) items to include.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sort FeedGetCrosspostThreadSort?
Sorting for thread replies.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_FeedGetCrosspostThreadInput value)) → TResult

Available on FeedGetCrosspostThreadInput, provided by the FeedGetCrosspostThreadInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_FeedGetCrosspostThreadInput value)?) → TResult?

Available on FeedGetCrosspostThreadInput, provided by the FeedGetCrosspostThreadInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_FeedGetCrosspostThreadInput value)?, {required TResult orElse()}) → TResult

Available on FeedGetCrosspostThreadInput, provided by the FeedGetCrosspostThreadInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(AtUri anchor, int limit, String? cursor, int depth, int parentHeight, FeedGetCrosspostThreadSort? sort, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on FeedGetCrosspostThreadInput, provided by the FeedGetCrosspostThreadInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this FeedGetCrosspostThreadInput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(AtUri anchor, int limit, String? cursor, int depth, int parentHeight, FeedGetCrosspostThreadSort? sort, Map<String, dynamic>? $unknown)) → TResult

Available on FeedGetCrosspostThreadInput, provided by the FeedGetCrosspostThreadInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(AtUri anchor, int limit, String? cursor, int depth, int parentHeight, FeedGetCrosspostThreadSort? sort, Map<String, dynamic>? $unknown)?) → TResult?

Available on FeedGetCrosspostThreadInput, provided by the FeedGetCrosspostThreadInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>