FeedGetCrosspostThreadInputPatterns extension

Adds pattern-matching-related methods to FeedGetCrosspostThreadInput.

on

Methods

map<TResult extends Object?>(TResult $default(_FeedGetCrosspostThreadInput value)) → TResult

Available on FeedGetCrosspostThreadInput, provided by the FeedGetCrosspostThreadInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_FeedGetCrosspostThreadInput value)?) → TResult?

Available on FeedGetCrosspostThreadInput, provided by the FeedGetCrosspostThreadInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_FeedGetCrosspostThreadInput value)?, {required TResult orElse()}) → TResult

Available on FeedGetCrosspostThreadInput, provided by the FeedGetCrosspostThreadInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(AtUri anchor, int limit, String? cursor, int depth, int parentHeight, FeedGetCrosspostThreadParametersSort? sort, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on FeedGetCrosspostThreadInput, provided by the FeedGetCrosspostThreadInputPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(AtUri anchor, int limit, String? cursor, int depth, int parentHeight, FeedGetCrosspostThreadParametersSort? sort, Map<String, dynamic>? $unknown)) → TResult

Available on FeedGetCrosspostThreadInput, provided by the FeedGetCrosspostThreadInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(AtUri anchor, int limit, String? cursor, int depth, int parentHeight, FeedGetCrosspostThreadParametersSort? sort, Map<String, dynamic>? $unknown)?) → TResult?

Available on FeedGetCrosspostThreadInput, provided by the FeedGetCrosspostThreadInputPatterns extension

A variant of when that fallback to returning null