depth property

int get depth
inherited

How many levels of reply depth should be included in response.

Implementation

@AtUriConverter() AtUri get anchor; int get limit; String? get cursor;/// How many levels of reply depth should be included in response.
 int get depth;