depth property

int get depth
inherited

The nesting level of this item in the thread. Depth 0 means the anchor item.

Implementation

String get $type;@AtUriConverter() AtUri get uri;/// The nesting level of this item in the thread. Depth 0 means the anchor item.
int get depth;