FeedReplyRecordPatterns extension

Adds pattern-matching-related methods to FeedReplyRecord.

on

Methods

map<TResult extends Object?>(TResult $default(_FeedReplyRecord value)) → TResult

Available on FeedReplyRecord, provided by the FeedReplyRecordPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_FeedReplyRecord value)?) → TResult?

Available on FeedReplyRecord, provided by the FeedReplyRecordPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_FeedReplyRecord value)?, {required TResult orElse()}) → TResult

Available on FeedReplyRecord, provided by the FeedReplyRecordPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String $type, String? text, List<RichtextFacet>? facets, ReplyRef reply, UFeedReplyMedia? media, List<String>? langs, UFeedReplyLabels? labels, DateTime createdAt, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on FeedReplyRecord, provided by the FeedReplyRecordPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(String $type, String? text, List<RichtextFacet>? facets, ReplyRef reply, UFeedReplyMedia? media, List<String>? langs, UFeedReplyLabels? labels, DateTime createdAt, Map<String, dynamic>? $unknown)) → TResult

Available on FeedReplyRecord, provided by the FeedReplyRecordPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String $type, String? text, List<RichtextFacet>? facets, ReplyRef reply, UFeedReplyMedia? media, List<String>? langs, UFeedReplyLabels? labels, DateTime createdAt, Map<String, dynamic>? $unknown)?) → TResult?

Available on FeedReplyRecord, provided by the FeedReplyRecordPatterns extension

A variant of when that fallback to returning null