FeedSearchPostsInput class abstract

Available extensions
Annotations
  • @freezed

Constructors

FeedSearchPostsInput({required String q, @FeedSearchPostsSortConverter() FeedSearchPostsSort? sort, @Default.new(25) int limit, String? cursor, Map<String, dynamic>? $unknown})
const
factory
FeedSearchPostsInput.fromJson(Map<String, Object?> json)
factory

Properties

$unknown Map<String, dynamic>?
no setterinherited
copyWith → $FeedSearchPostsInputCopyWith<FeedSearchPostsInput>
Create a copy of FeedSearchPostsInput with the given fields replaced by the non-null parameter values.
no setterinherited
cursor String?
Optional pagination mechanism; may not necessarily allow scrolling through entire result set.
no setterinherited
hasCursor bool

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
hasNotCursor bool

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputExtension extension

no setter
hasNotSort bool

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputExtension extension

no setter
hasSort bool

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputExtension extension

no setter
limit int
no setterinherited
q String
Search query string; to match against post descriptions and such.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sort FeedSearchPostsSort?
Specifies the ranking order of results.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_FeedSearchPostsInput value)) → TResult

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_FeedSearchPostsInput value)?) → TResult?

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_FeedSearchPostsInput value)?, {required TResult orElse()}) → TResult

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String q, FeedSearchPostsSort? sort, int limit, String? cursor, Map<String, dynamic>? $unknown)?, {required TResult orElse()}) → TResult

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this FeedSearchPostsInput to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String q, FeedSearchPostsSort? sort, int limit, String? cursor, Map<String, dynamic>? $unknown)) → TResult

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String q, FeedSearchPostsSort? sort, int limit, String? cursor, Map<String, dynamic>? $unknown)?) → TResult?

Available on FeedSearchPostsInput, provided by the FeedSearchPostsInputPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

knownProps → const List<String>