cursor property

String? get cursor
inherited

Optional pagination mechanism; may not necessarily allow scrolling through entire result set.

Implementation

@FeedSearchPostsSortConverter() FeedSearchPostsSort? get sort; int get limit;/// Optional pagination mechanism; may not necessarily allow scrolling through entire result set.
 String? get cursor;