depth property
How many levels of reply depth should be included in response.
Implementation
@AtUriConverter() AtUri get anchor; int get limit; String? get cursor;/// How many levels of reply depth should be included in response.
int get depth;
How many levels of reply depth should be included in response.
@AtUriConverter() AtUri get anchor; int get limit; String? get cursor;/// How many levels of reply depth should be included in response.
int get depth;